@@ -1,10 +1,10 @@
 import hddm
 
 # Load data from csv file into a NumPy structured array
-data = hddm.load_csv('simple_subj_data.csv')
+data = hddm.load_csv("simple_difficulty.csv")
 
 # Create a HDDM model multi object
-model = hddm.HDDM(data, depends_on={'v':'difficulty'})
+model = hddm.HDDM(data, depends_on={"v": "difficulty"})
 
 # Create model and start MCMC sampling
 model.sample(10000, burn=5000)
@@ -13,5 +13,5 @@ model.sample(10000, burn=5000)
 model.print_stats()
 
 # Plot posterior distributions and theoretical RT distributions
-hddm.plot_posteriors(model)
-hddm.plot_post_pred(model.nodes)
+model.plot_posteriors(save=True)
+model.plot_posterior_predictive(save=True)
